@@ -1,14 +1,15 @@
 package Org::To::Base;
 
+our $DATE = '2015-08-18'; # DATE
+our $VERSION = '0.15'; # VERSION
+
 use 5.010001;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use List::Util qw(first);
 use Moo;
 use experimental 'smartmatch';
 
-our $VERSION = '0.14'; # VERSION
-
 has include_tags => (is => 'rw');
 has exclude_tags => (is => 'rw');
 
@@ -144,7 +145,7 @@ Org::To::Base - Base class for Org exporters
 
 =head1 VERSION
 
-This document describes version 0.14 of Org::To::Base (from Perl distribution Org-To-HTML), released on 2014-08-16.
+This document describes version 0.15 of Org::To::Base (from Perl distribution Org-To-HTML), released on 2015-08-18.
 
 =head1 SYNOPSIS
 
@@ -197,7 +198,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Org-To-HTM
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Org-To-HTML>.
+Source repository is at L<https://github.com/perlancar/perl-Org-To-HTML>.
 
 =head1 BUGS
 
@@ -209,11 +210,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
