@@ -1,7 +1,10 @@
 package Org::To::HTML;
 
+our $DATE = '2015-08-18'; # DATE
+our $VERSION = '0.15'; # VERSION
+
 use 5.010;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use vars qw($VERSION);
 
@@ -14,8 +17,6 @@ use experimental 'smartmatch';
 with 'Org::To::Role';
 extends 'Org::To::Base';
 
-our $VERSION = '0.14'; # VERSION
-
 require Exporter;
 our @ISA;
 push @ISA,       qw(Exporter);
@@ -391,7 +392,7 @@ Org::To::HTML - Export Org document to HTML
 
 =head1 VERSION
 
-This document describes version 0.14 of Org::To::HTML (from Perl distribution Org-To-HTML), released on 2014-08-16.
+This document describes version 0.15 of Org::To::HTML (from Perl distribution Org-To-HTML), released on 2015-08-18.
 
 =head1 SYNOPSIS
 
@@ -419,21 +420,17 @@ Export Org format to HTML. To customize, you can subclass this module.
 
 A command-line utility is included: L<org-to-html>.
 
-This module uses L<Log::Any> logging framework.
-
-This module uses L<Moo> for object system.
-
-This module has L<Rinci> metadata.
-
 =head1 FUNCTIONS
 
 
 =head2 org_to_html(%args) -> [status, msg, result, meta]
 
-Export Org document to HTML.
+{en_US Export Org document to HTML}.
 
+{en_US 
 This is the non-OO interface. For more customization, consider subclassing
 Org::To::HTML.
+}
 
 Arguments ('*' denotes required arguments):
 
@@ -441,55 +438,59 @@ Arguments ('*' denotes required arguments):
 
 =item * B<css_url> => I<str>
 
-Add a link to CSS document.
+{en_US Add a link to CSS document}.
 
-=item * B<exclude_tags> => I<array>
+=item * B<exclude_tags> => I<array[str]>
 
-Exclude trees that carry one of these tags.
+{en_US Exclude trees that carry one of these tags}.
 
+{en_US 
 If the whole document doesn't have any of these tags, then the whole document
 will be exported. Otherwise, trees that do not carry one of these tags will be
 excluded. If a selected tree is a subtree, the heading hierarchy above it will
 also be selected for export, but not the text below those headings.
 
 exclude_tags is evaluated after include_tags.
+}
 
 =item * B<html_title> => I<str>
 
-HTML document title, defaults to source_file.
+{en_US HTML document title, defaults to source_file}.
 
-=item * B<include_tags> => I<array>
+=item * B<include_tags> => I<array[str]>
 
-Include trees that carry one of these tags.
+{en_US Include trees that carry one of these tags}.
 
+{en_US 
 Works like Org's 'org-export-select-tags' variable. If the whole document
 doesn't have any of these tags, then the whole document will be exported.
 Otherwise, trees that do not carry one of these tags will be excluded. If a
 selected tree is a subtree, the heading hierarchy above it will also be selected
 for export, but not the text below those headings.
+}
 
 =item * B<naked> => I<bool>
 
-Don't wrap exported HTML with HTML/HEAD/BODY elements.
+{en_US Don't wrap exported HTML with HTML/HEAD/BODY elements}.
 
 =item * B<source_file> => I<str>
 
-Source Org file to export.
+{en_US Source Org file to export}.
 
 =item * B<source_str> => I<str>
 
-Alternatively you can specify Org string directly.
+{en_US Alternatively you can specify Org string directly}.
 
 =item * B<target_file> => I<str>
 
-HTML file to write to.
+{en_US HTML file to write to}.
 
+{en_US 
 If not specified, HTML string will be returned.
+}
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -499,7 +500,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 =for Pod::Coverage ^(export_.+)$
 
@@ -541,7 +542,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Org-To-HTM
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Org-To-HTML>.
+Source repository is at L<https://github.com/perlancar/perl-Org-To-HTML>.
 
 =head1 BUGS
 
@@ -553,11 +554,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
