@@ -1,6 +1,7 @@
 package Org::To::HTML::Link::cpandist;
 
-our $VERSION = '0.14'; # VERSION
+our $DATE = '2015-08-18'; # DATE
+our $VERSION = '0.15'; # VERSION
 
 1;
 # ABSTRACT: cpandist
@@ -17,7 +18,7 @@ Org::To::HTML::Link::cpandist - cpandist
 
 =head1 VERSION
 
-This document describes version 0.14 of Org::To::HTML::Link::cpandist (from Perl distribution Org-To-HTML), released on 2014-08-16.
+This document describes version 0.15 of Org::To::HTML::Link::cpandist (from Perl distribution Org-To-HTML), released on 2015-08-18.
 
 =head1 HOMEPAGE
 
@@ -25,7 +26,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Org-To-HTM
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Org-To-HTML>.
+Source repository is at L<https://github.com/perlancar/perl-Org-To-HTML>.
 
 =head1 BUGS
 
@@ -37,11 +38,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
