@@ -1,15 +1,16 @@
 package Org::To::Role;
 
+our $DATE = '2015-08-18'; # DATE
+our $VERSION = '0.15'; # VERSION
+
 use 5.010;
 use strict;
 use warnings;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use Moo::Role;
 use String::Escape qw/elide printable/;
 
-our $VERSION = '0.14'; # VERSION
-
 requires 'export_document';
 requires 'export_block';
 requires 'export_fixed_width_section';
@@ -46,7 +47,7 @@ Org::To::Role - Role for Org exporters
 
 =head1 VERSION
 
-This document describes version 0.14 of Org::To::Role (from Perl distribution Org-To-HTML), released on 2014-08-16.
+This document describes version 0.15 of Org::To::Role (from Perl distribution Org-To-HTML), released on 2015-08-18.
 
 =head1 HOMEPAGE
 
@@ -54,7 +55,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Org-To-HTM
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Org-To-HTML>.
+Source repository is at L<https://github.com/perlancar/perl-Org-To-HTML>.
 
 =head1 BUGS
 
@@ -66,11 +67,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
